From mboxrd@z Thu Jan  1 00:00:00 1970
From: Klemens Nanni <klemens@posteo.de>
To: list+catgirl@causal.agency
Subject: [PATCH] Update window status only on message at/above visiblity threshold
Date: Wed, 28 Jul 2021 17:19:55 +0000
Message-Id: <20210728171955.38274-1-klemens@posteo.de>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

If a window is set to highlight only, i.e. the status looks like
	2++ #highlight-or-nothing
the user is probably not interested in window status updates, e.g. new
unhighlighted messages, unless they reach the set visiblity threshold.

catgirl won't print unhighlighted messages in the window as expected,
but the status would still be updated on such uninteresting noise, i.e.
	2++ #highlight-or-nothing +34

Make window status update semantics match message visibility semantics.
Afterall, status changes result in UI redraws/disruptions/termnial bells
and whatnot.
---
 ui.c | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/ui.c b/ui.c
index 03d77bb..8d691a4 100644
--- a/ui.c
+++ b/ui.c
@@ -407,6 +407,7 @@ static void statusUpdate(void) {
 	for (uint num = 0; num < windows.len; ++num) {
 		const struct Window *window = windows.ptrs[num];
 		if (num != windows.show && !window->scroll) {
+			if (window->heat < window->thresh) continue;
 			if (window->heat < Warm) continue;
 			if (window->mute && window->heat < Hot) continue;
 		}
@@ -437,6 +438,7 @@ static void statusUpdate(void) {
 	wclrtoeol(status);
 
 	const struct Window *window = windows.ptrs[windows.show];
+	if (window->heat < window->thresh) return;
 	char *end = &title[sizeof(title)];
 	char *ptr = seprintf(
 		title, end, "%s %s", network.name, idNames[window->id]
-- 
2.32.0


